from user_agent import generate_user_agent
class iq:
    def run():
        print("Hello Python :)")
        return " Dont Forgot, Install Library :)"
class fake:
        def get():
            return (generate_user_agent())
